@@ -7,3 +7,7 @@ class ordinary_dividend_income(Variable):
     label = "Ordinary dividend income"
     unit = USD
     definition_period = YEAR
+
+    formula = sum_of_variables(
+        ["qualified_dividend_income", "non_qualified_dividend_income"]
+    )
